# OAIClass2MessagesApi

All URIs are relative to *https://api.chat-api.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**forwardMessage**](OAIClass2MessagesApi.md#forwardmessage) | **POST** /forwardMessage | Forwarding messages to a new or existing chat.
[**getMessages**](OAIClass2MessagesApi.md#getmessages) | **GET** /messages | Get a list of messages.
[**sendContact**](OAIClass2MessagesApi.md#sendcontact) | **POST** /sendContact | Sending a contact or contact list to a new or existing chat.
[**sendFile**](OAIClass2MessagesApi.md#sendfile) | **POST** /sendFile | Send a file to a new or existing chat.
[**sendLink**](OAIClass2MessagesApi.md#sendlink) | **POST** /sendLink | Send text with link and link&#39;s preview to a new or existing chat.
[**sendLocation**](OAIClass2MessagesApi.md#sendlocation) | **POST** /sendLocation | Sending a location to a new or existing chat.
[**sendMessage**](OAIClass2MessagesApi.md#sendmessage) | **POST** /sendMessage | Send a message to a new or existing chat.
[**sendPTT**](OAIClass2MessagesApi.md#sendptt) | **POST** /sendPTT | Send a ptt-audio to a new or existing chat.
[**sendVCard**](OAIClass2MessagesApi.md#sendvcard) | **POST** /sendVCard | Sending a vcard to a new or existing chat.


# **forwardMessage**
```objc
-(NSURLSessionTask*) forwardMessageWithForwardMessageRequest: (OAIForwardMessageRequest*) forwardMessageRequest
        completionHandler: (void (^)(OAISendMessageStatus* output, NSError* error)) handler;
```

Forwarding messages to a new or existing chat.

Only one of two parameters is needed to determine the destination - chatId or phone.

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];


OAIForwardMessageRequest* forwardMessageRequest = [[OAIForwardMessageRequest alloc] init]; // 

OAIClass2MessagesApi*apiInstance = [[OAIClass2MessagesApi alloc] init];

// Forwarding messages to a new or existing chat.
[apiInstance forwardMessageWithForwardMessageRequest:forwardMessageRequest
          completionHandler: ^(OAISendMessageStatus* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass2MessagesApi->forwardMessage: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **forwardMessageRequest** | [**OAIForwardMessageRequest***](OAIForwardMessageRequest.md)|  | 

### Return type

[**OAISendMessageStatus***](OAISendMessageStatus.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded, application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getMessages**
```objc
-(NSURLSessionTask*) getMessagesWithLastMessageNumber: (NSNumber*) lastMessageNumber
    last: (NSNumber*) last
    chatId: (NSString*) chatId
    limit: (NSNumber*) limit
    minTime: (NSNumber*) minTime
    maxTime: (NSNumber*) maxTime
        completionHandler: (void (^)(OAIMessages* output, NSError* error)) handler;
```

Get a list of messages.

To receive only new messages, pass the **lastMessageNumber** parameter from the last query.  Files from messages are guaranteed to be stored only for 30 days and can be deleted. Download the files as soon as you get to your server.

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];


NSNumber* lastMessageNumber = 0; // The lastMessageNumber parameter from the last response (optional)
NSNumber* last = true; // Displays the last 100 messages. If this parameter is passed, then lastMessageNumber is ignored. (optional) (default to @(NO))
NSString* chatId = 17633123456@c.us; // Filter messages by chatId  Chat ID from the message list. Examples: 17633123456@c.us for private messages and 17680561234-1479621234@g.us for the group. (optional)
NSNumber* limit = 100; // Sets length of the message list. Default 100. With value 0 returns all messages. (optional)
NSNumber* minTime = 946684800; // Filter messages received after specified time. Example: 946684800. (optional)
NSNumber* maxTime = 946684800; // Filter messages received before specified time. Example: 946684800. (optional)

OAIClass2MessagesApi*apiInstance = [[OAIClass2MessagesApi alloc] init];

// Get a list of messages.
[apiInstance getMessagesWithLastMessageNumber:lastMessageNumber
              last:last
              chatId:chatId
              limit:limit
              minTime:minTime
              maxTime:maxTime
          completionHandler: ^(OAIMessages* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass2MessagesApi->getMessages: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **lastMessageNumber** | **NSNumber***| The lastMessageNumber parameter from the last response | [optional] 
 **last** | **NSNumber***| Displays the last 100 messages. If this parameter is passed, then lastMessageNumber is ignored. | [optional] [default to @(NO)]
 **chatId** | **NSString***| Filter messages by chatId  Chat ID from the message list. Examples: 17633123456@c.us for private messages and 17680561234-1479621234@g.us for the group. | [optional] 
 **limit** | **NSNumber***| Sets length of the message list. Default 100. With value 0 returns all messages. | [optional] 
 **minTime** | **NSNumber***| Filter messages received after specified time. Example: 946684800. | [optional] 
 **maxTime** | **NSNumber***| Filter messages received before specified time. Example: 946684800. | [optional] 

### Return type

[**OAIMessages***](OAIMessages.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **sendContact**
```objc
-(NSURLSessionTask*) sendContactWithSendContactRequest: (OAISendContactRequest*) sendContactRequest
        completionHandler: (void (^)(OAISendMessageStatus* output, NSError* error)) handler;
```

Sending a contact or contact list to a new or existing chat.

Only one of two parameters is needed to determine the destination - chatId or phone.

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];


OAISendContactRequest* sendContactRequest = [[OAISendContactRequest alloc] init]; // 

OAIClass2MessagesApi*apiInstance = [[OAIClass2MessagesApi alloc] init];

// Sending a contact or contact list to a new or existing chat.
[apiInstance sendContactWithSendContactRequest:sendContactRequest
          completionHandler: ^(OAISendMessageStatus* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass2MessagesApi->sendContact: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sendContactRequest** | [**OAISendContactRequest***](OAISendContactRequest.md)|  | 

### Return type

[**OAISendMessageStatus***](OAISendMessageStatus.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded, application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **sendFile**
```objc
-(NSURLSessionTask*) sendFileWithSendFileRequest: (OAISendFileRequest*) sendFileRequest
        completionHandler: (void (^)(OAISendMessageStatus* output, NSError* error)) handler;
```

Send a file to a new or existing chat.

Only one of two parameters is needed to determine the destination - chatId or phone.

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];


OAISendFileRequest* sendFileRequest = [[OAISendFileRequest alloc] init]; // 

OAIClass2MessagesApi*apiInstance = [[OAIClass2MessagesApi alloc] init];

// Send a file to a new or existing chat.
[apiInstance sendFileWithSendFileRequest:sendFileRequest
          completionHandler: ^(OAISendMessageStatus* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass2MessagesApi->sendFile: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sendFileRequest** | [**OAISendFileRequest***](OAISendFileRequest.md)|  | 

### Return type

[**OAISendMessageStatus***](OAISendMessageStatus.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded, application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **sendLink**
```objc
-(NSURLSessionTask*) sendLinkWithSendLinkRequest: (OAISendLinkRequest*) sendLinkRequest
        completionHandler: (void (^)(OAISendMessageStatus* output, NSError* error)) handler;
```

Send text with link and link's preview to a new or existing chat.

Only one of two parameters is needed to determine the destination - chatId or phone.

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];


OAISendLinkRequest* sendLinkRequest = [[OAISendLinkRequest alloc] init]; // 

OAIClass2MessagesApi*apiInstance = [[OAIClass2MessagesApi alloc] init];

// Send text with link and link's preview to a new or existing chat.
[apiInstance sendLinkWithSendLinkRequest:sendLinkRequest
          completionHandler: ^(OAISendMessageStatus* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass2MessagesApi->sendLink: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sendLinkRequest** | [**OAISendLinkRequest***](OAISendLinkRequest.md)|  | 

### Return type

[**OAISendMessageStatus***](OAISendMessageStatus.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded, application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **sendLocation**
```objc
-(NSURLSessionTask*) sendLocationWithSendLocationRequest: (OAISendLocationRequest*) sendLocationRequest
        completionHandler: (void (^)(OAISendMessageStatus* output, NSError* error)) handler;
```

Sending a location to a new or existing chat.

Only one of two parameters is needed to determine the destination - chatId or phone.

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];


OAISendLocationRequest* sendLocationRequest = [[OAISendLocationRequest alloc] init]; // 

OAIClass2MessagesApi*apiInstance = [[OAIClass2MessagesApi alloc] init];

// Sending a location to a new or existing chat.
[apiInstance sendLocationWithSendLocationRequest:sendLocationRequest
          completionHandler: ^(OAISendMessageStatus* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass2MessagesApi->sendLocation: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sendLocationRequest** | [**OAISendLocationRequest***](OAISendLocationRequest.md)|  | 

### Return type

[**OAISendMessageStatus***](OAISendMessageStatus.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded, application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **sendMessage**
```objc
-(NSURLSessionTask*) sendMessageWithSendMessageRequest: (OAISendMessageRequest*) sendMessageRequest
        completionHandler: (void (^)(OAISendMessageStatus* output, NSError* error)) handler;
```

Send a message to a new or existing chat.

The message will be added to the queue for sending and delivered even if the phone is disconnected from the Internet or authorization is not passed.  Only one of two parameters is needed to determine the destination - chatId or phone.

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];


OAISendMessageRequest* sendMessageRequest = [[OAISendMessageRequest alloc] init]; // 

OAIClass2MessagesApi*apiInstance = [[OAIClass2MessagesApi alloc] init];

// Send a message to a new or existing chat.
[apiInstance sendMessageWithSendMessageRequest:sendMessageRequest
          completionHandler: ^(OAISendMessageStatus* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass2MessagesApi->sendMessage: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sendMessageRequest** | [**OAISendMessageRequest***](OAISendMessageRequest.md)|  | 

### Return type

[**OAISendMessageStatus***](OAISendMessageStatus.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded, application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **sendPTT**
```objc
-(NSURLSessionTask*) sendPTTWithSendPTTRequest: (OAISendPTTRequest*) sendPTTRequest
        completionHandler: (void (^)(OAISendMessageStatus* output, NSError* error)) handler;
```

Send a ptt-audio to a new or existing chat.

Only one of two parameters is needed to determine the destination - chatId or phone.

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];


OAISendPTTRequest* sendPTTRequest = [[OAISendPTTRequest alloc] init]; // 

OAIClass2MessagesApi*apiInstance = [[OAIClass2MessagesApi alloc] init];

// Send a ptt-audio to a new or existing chat.
[apiInstance sendPTTWithSendPTTRequest:sendPTTRequest
          completionHandler: ^(OAISendMessageStatus* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass2MessagesApi->sendPTT: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sendPTTRequest** | [**OAISendPTTRequest***](OAISendPTTRequest.md)|  | 

### Return type

[**OAISendMessageStatus***](OAISendMessageStatus.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded, application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **sendVCard**
```objc
-(NSURLSessionTask*) sendVCardWithSendVCardRequest: (OAISendVCardRequest*) sendVCardRequest
        completionHandler: (void (^)(OAISendMessageStatus* output, NSError* error)) handler;
```

Sending a vcard to a new or existing chat.

Only one of two parameters is needed to determine the destination - chatId or phone.

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];


OAISendVCardRequest* sendVCardRequest = [[OAISendVCardRequest alloc] init]; // 

OAIClass2MessagesApi*apiInstance = [[OAIClass2MessagesApi alloc] init];

// Sending a vcard to a new or existing chat.
[apiInstance sendVCardWithSendVCardRequest:sendVCardRequest
          completionHandler: ^(OAISendMessageStatus* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass2MessagesApi->sendVCard: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sendVCardRequest** | [**OAISendVCardRequest***](OAISendVCardRequest.md)|  | 

### Return type

[**OAISendMessageStatus***](OAISendMessageStatus.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded, application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

